/* ********************************************* */
//
// ACES IDT for Canon EOS C500 (Type A)
//
// Version: 1.0 2013/01/07
// Copyright(c) 2013 Canon Inc. All Rights Reserved.

/* ********************************************* */
//
// Camera     : EOS C500
// Output     : 3G-SDI 1 and 2, Cinema RAW(.rmf) file, Mon.1 and 2
// Illuminant : Tungsten (ISO 7589 Studio Tungsten)
//
//
// [ NOTE ]                          
//
// +This IDT is defined for images those were shot under
//  illumination sources with low color temperature like Tungsten. 
//
// +This IDT can be applied for the images from 3G-SDI 1 / 2,
//  Cinema RAW(.rmf) file or Mon.1 / 2.
//
// +Different IDT should be refered for MXF file and other outputs
//  such as HD-SDI / HDMI.
// 
/* ********************************************* */


/* ============ SUBFUNCTIONS ============ */
/* CanonLog IRE to Linear */
float CanonLog_to_linear (
	float clog_ire
)
{
	return (pow(10,(clog_ire-0.0730597)/0.529136)-1)/10.1596;

}


/* ============ Main Algorithm ============ */
void main
(   input varying float rIn,
    input varying float gIn,
    input varying float bIn,
    input varying float aIn,
    output varying float rOut,
    output varying float gOut,
    output varying float bOut,
    output varying float aOut
)
{
	// CodeValue to IRE, ire = (cv-64)/(940-64)
	float CLogIRE[3];
	CLogIRE[0] = (rIn*1023 - 64) / 876;
	CLogIRE[1] = (gIn*1023 - 64) / 876;
	CLogIRE[2] = (bIn*1023 - 64) / 876;

	// Canon-Log to linear 
	float lin[3];
	lin[0] = CanonLog_to_linear( CLogIRE[0]);
	lin[1] = CanonLog_to_linear( CLogIRE[1]);
	lin[2] = CanonLog_to_linear( CLogIRE[2]);
	
	// ACES conversion matrix
	float aces[3];

	aces[0] = 0.566996399 * lin[0] +0.365079418 * lin[1] + 0.067924183 * lin[2];
	aces[1] = 0.070901044 * lin[0] +0.880331008 * lin[1] + 0.048767948 * lin[2];
	aces[2] = 0.073013542 * lin[0] -0.066540862 * lin[1] + 0.99352732 * lin[2];



	rOut = aces[0];
	gOut = aces[1];
	bOut = aces[2];
	aOut = aIn;
}


/* ============ End of IDT ============ */

